# Orange3 Flow Immersive

This is the Orange3 add-on for pushing data to Flow.

## Installation

### Production

Open Orange3, navigate to `Options -> Add-ons...`, select `Add more...`, type in `orange3-flowgl`, and press `Add`. 

### Development

In the same python environment as Orange3 is installed, run:

```bash
pip install -e .
```
